.. PEtab GUI documentation master file, created by
   sphinx-quickstart on Thu Jul 31 13:45:56 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=================================================
PEtab-GUI - A graphical user interface for PEtab
=================================================

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.15355752.svg
   :target: https://doi.org/10.5281/zenodo.15355752
   :alt: DOI

.. image:: https://readthedocs.org/projects/petab-gui/badge/?version=latest
   :target: https://petab-gui.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

**PEtab-GUI** is a user-friendly graphical interface for creating and managing parameter estimation problems using the `PEtab <https://petab.readthedocs.io/en/latest/>`_ format.

.. note::
   Current version: |release|

Quick Links
-----------

* `GitHub Repository <https://github.com/PEtab-dev/PEtab-GUI>`_
* `Issue Tracker <https://github.com/PEtab-dev/PEtab-GUI/issues>`_
* `PEtab Documentation <https://petab.readthedocs.io/en/latest/>`_

Overview
--------

PEtab-GUI simplifies the process of creating parameter estimation problems for systems biology models. It provides an intuitive interface for:

* Creating and editing SBML models
* Defining experimental conditions
* Specifying measurements and observables
* Setting up parameter estimation configurations
* Exporting to the PEtab format

Getting Started
---------------

To get started with PEtab GUI, check out the :doc:`installation instructions <readme>` and the :doc:`tutorial <tutorial>`.

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   readme
   tutorial
   next_steps

.. toctree::
   :maxdepth: 1
   :caption: Development

   GitHub Repository <https://github.com/PEtab-dev/PEtab-GUI>
   contributing
